@@ -102,12 +102,20 @@ class RateLimitException(TraktException):
     http_code = 429
     message = 'Rate Limit Exceeded'
 
+    @property
+    def retry_after(self):
+        return int(self.response.headers.get("Retry-After", 1))
+
 
 class TraktInternalException(TraktException):
     """TraktException type to be raised when a 500 error is raised"""
     http_code = 500
     message = 'Internal Server Error'
 
+    @property
+    def error_message(self):
+        return self.response.headers.get("x-error-message", None)
+
 
 class TraktBadGateway(TraktException):
     """TraktException type to be raised when a 502 error is raised"""
